<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="es">
<context>
    <name>AsciiFile</name>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="35"/>
        <location filename="../asciifile/asciifile.cpp" line="41"/>
        <source>Read ascii points</source>
        <translation>Leer puntos ASCII</translation>
    </message>
</context>
<context>
    <name>ImportShp</name>
    <message>
        <location filename="../importshp/importshp.cpp" line="40"/>
        <source>Import ESRI Shapefile</source>
        <translation>Importar archivo Shapefile de ESRI</translation>
    </message>
</context>
<context>
    <name>LC_Align</name>
    <message>
        <location filename="../align/align.cpp" line="20"/>
        <location filename="../align/align.cpp" line="27"/>
        <source>Align</source>
        <translation>Alinear</translation>
    </message>
    <message>
        <location filename="../align/align.cpp" line="40"/>
        <source>first base point:</source>
        <translation>primer punto base:</translation>
    </message>
    <message>
        <location filename="../align/align.cpp" line="42"/>
        <source>first target point:</source>
        <translation>primer punto de destino:</translation>
    </message>
    <message>
        <location filename="../align/align.cpp" line="44"/>
        <source>second base point:</source>
        <translation>segundo punto base:</translation>
    </message>
    <message>
        <location filename="../align/align.cpp" line="46"/>
        <source>second target point:</source>
        <translation>segundo punto de destino:</translation>
    </message>
</context>
<context>
    <name>LC_Gear</name>
    <message>
        <location filename="../gear/gear.cpp" line="33"/>
        <source>Gear creation plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gear/gear.cpp" line="40"/>
        <source>Gear plugin</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LC_List</name>
    <message>
        <location filename="../list/list.cpp" line="23"/>
        <location filename="../list/list.cpp" line="30"/>
        <source>List entities</source>
        <translation>Listar entidades</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="46"/>
        <source>n</source>
        <translation>n</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="60"/>
        <source>Empty Entity</source>
        <translation>Entidad vacía</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="67"/>
        <source>X</source>
        <translation>X</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="67"/>
        <source>Y</source>
        <translation>Y</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="77"/>
        <source>Layer</source>
        <translation>Capa</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="79"/>
        <source>Color</source>
        <translation>Color</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="80"/>
        <source>Line type</source>
        <translation>Tipo de línea</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="81"/>
        <source>Line thickness</source>
        <translation>Grosor de línea</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="82"/>
        <source>ID</source>
        <translation>ID</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="88"/>
        <source>POINT</source>
        <translation>PUNTO</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="89"/>
        <location filename="../list/list.cpp" line="218"/>
        <source>in point</source>
        <translation>en el punto</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="94"/>
        <source>LINE</source>
        <translation>LÍNEA</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="99"/>
        <source>from point</source>
        <translation>desde el punto</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="102"/>
        <source>to point</source>
        <translation>hasta el punto</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="107"/>
        <location filename="../list/list.cpp" line="131"/>
        <source>length</source>
        <translation>longitud</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="112"/>
        <source>Angle in XY plane</source>
        <translation>Ángulo en el plano XY</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="113"/>
        <source>Inc.</source>
        <translation>Inc.</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="118"/>
        <source>ARC</source>
        <translation>ARCO</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="119"/>
        <location filename="../list/list.cpp" line="135"/>
        <location filename="../list/list.cpp" line="145"/>
        <source>center point</source>
        <translation>punto del centro</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="125"/>
        <location filename="../list/list.cpp" line="139"/>
        <location filename="../list/list.cpp" line="222"/>
        <source>radius</source>
        <translation>radio</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="126"/>
        <source>initial angle</source>
        <translation>ángulo inicial</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="127"/>
        <source>final angle</source>
        <translation>ángulo final</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="134"/>
        <source>CIRCLE</source>
        <translation>CÍRCULO</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="140"/>
        <source>circumference</source>
        <translation>circunferencia</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="141"/>
        <source>area</source>
        <translation>área</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="144"/>
        <source>ELLIPSE</source>
        <translation>ELIPSE</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="148"/>
        <source>major axis</source>
        <translation>eje mayor</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="166"/>
        <source>CONSTRUCTIONLINE</source>
        <translation>LÍNEA DE CONSTRUCCIÓN</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="169"/>
        <source>OVERLAYBOX</source>
        <translation>COBERTURA</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="172"/>
        <source>SOLID</source>
        <translation>SÓLIDO</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="176"/>
        <source>MTEXT</source>
        <translation>TEXTOM</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="179"/>
        <source>TEXT</source>
        <translation>TEXTO</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="182"/>
        <source>INSERT</source>
        <translation>INSERTAR</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="185"/>
        <source>Name</source>
        <translation>Nombre</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="187"/>
        <source>Insertion point</source>
        <translation>Punto de inserción</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="190"/>
        <source>Scale</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="193"/>
        <source>Rotation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="199"/>
        <source>Columns/Rows</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="203"/>
        <source>Column/Row Spacing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="210"/>
        <source>POLYLINE</source>
        <translation>POLILÍNEA</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="211"/>
        <source>Closed</source>
        <translation>Cerrada</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="212"/>
        <source>No</source>
        <translation>No</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="212"/>
        <source>Yes</source>
        <translation>Si</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="213"/>
        <source>Vertices</source>
        <translation>Vértices</translation>
    </message>
    <message>
        <source>curvature</source>
        <translation type="obsolete">curvatura</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="227"/>
        <source>IMAGE</source>
        <translation>IMAGEN</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="230"/>
        <source>SPLINE</source>
        <translation>SPLINE</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="233"/>
        <source>SPLINEPOINTS</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="236"/>
        <source>HATCH</source>
        <translation>SOMBREADO</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="239"/>
        <source>DIMLEADER</source>
        <translation>DIMGUÍA</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="242"/>
        <source>DIMALIGNED</source>
        <translation>DIMALINEADO</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="245"/>
        <source>DIMLINEAR</source>
        <translation>DIMLINEAL</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="248"/>
        <source>DIMRADIAL</source>
        <translation>DIMRADIAL</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="251"/>
        <source>DIMDIAMETRIC</source>
        <translation>DIMDIÁMETRO</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="254"/>
        <source>DIMANGULAR</source>
        <translation>DIMANGULAR</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="257"/>
        <source>UNKNOWN</source>
        <translation>DESCONOCIDO</translation>
    </message>
</context>
<context>
    <name>LC_SameProp</name>
    <message>
        <location filename="../sameprop/sameprop.cpp" line="21"/>
        <location filename="../sameprop/sameprop.cpp" line="28"/>
        <source>Same properties</source>
        <translation>Igualar propiedades</translation>
    </message>
    <message>
        <location filename="../sameprop/sameprop.cpp" line="41"/>
        <source>select original entity:</source>
        <translation>selecciona entidad original:</translation>
    </message>
    <message>
        <location filename="../sameprop/sameprop.cpp" line="43"/>
        <source>select entities to change</source>
        <translation>Seleccionar entidades a cambiar</translation>
    </message>
</context>
<context>
    <name>LC_Sample</name>
    <message>
        <location filename="../sample/sample.cpp" line="26"/>
        <location filename="../sample/sample.cpp" line="33"/>
        <source>Sample plugin</source>
        <translation>Plugin de ejemplo</translation>
    </message>
</context>
<context>
    <name>PicFile</name>
    <message>
        <location filename="../picfile/picfile.cpp" line="36"/>
        <source>Read PIC file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../picfile/picfile.cpp" line="42"/>
        <source>import PIC file</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>dibPunto</name>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="229"/>
        <source>Read ascii points</source>
        <translation>Leer puntos ascii</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="235"/>
        <source>File...</source>
        <translation>Archivo...</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="242"/>
        <source>Format:</source>
        <translation>Formato:</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="244"/>
        <source>Space Separator</source>
        <translation>Separado por espacios</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="244"/>
        <source>Tab Separator</source>
        <translation>Separado por tabuladores</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="244"/>
        <source>Comma Separator</source>
        <translation>Separado por comas</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="244"/>
        <source>Space in Columns</source>
        <translation>Espacio en Columnas</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="244"/>
        <source>*.odb for Psion 2</source>
        <translation>*.odb de Psion 2</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="246"/>
        <source>Connect points</source>
        <translation>Conectar puntos</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="254"/>
        <source>2D Point</source>
        <translation>Punto 2D</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="254"/>
        <source>Draw 2D Point</source>
        <translation>Dibujar Punto 2D</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="255"/>
        <source>3D Point</source>
        <translation>Punto 3D</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="255"/>
        <source>Draw 3D Point</source>
        <translation>Dibujar Punto 3D</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="256"/>
        <source>Point Number</source>
        <translation>Número del Punto</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="256"/>
        <source>Draw point number</source>
        <translation>Dibujar número del punto</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="257"/>
        <source>Point Elevation</source>
        <translation>Elevación del Punto</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="257"/>
        <source>Draw point elevation</source>
        <translation>Dibujar cota del punto</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="258"/>
        <source>Point Code</source>
        <translation>Código del Punto</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="258"/>
        <source>Draw point code</source>
        <translation>Dibuje el código del punto</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="272"/>
        <source>Accept</source>
        <translation>Aceptar</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="277"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="307"/>
        <source>Select file</source>
        <translation>Seleccionar archivo</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="314"/>
        <source>Point 2D layer is empty</source>
        <translation>Capa punto 2D esta vacia</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="317"/>
        <source>Point 3D layer is empty</source>
        <translation>Capa de los puntos 3D vacía</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="320"/>
        <source>Point elevation layer is empty</source>
        <translation>Capa de la cota de los puntos esta vacía</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="321"/>
        <source>Point elevation height is empty</source>
        <translation>Altura del texto de cota está vacía</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="322"/>
        <source>Point elevation separation is empty</source>
        <translation>La separación del punto de elevación está vacía</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="325"/>
        <source>Point number layer is empty</source>
        <translation>La capa del número del puntos está vacía</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="326"/>
        <source>Point number height is empty</source>
        <translation>La altura del punto de elevación está vacía</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="327"/>
        <source>Point number separation is empty</source>
        <translation>La separación del número del punto está vacía</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="330"/>
        <source>Point code layer is empty</source>
        <translation>Capa en referencia de punto está vacía</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="331"/>
        <source>Point code height is empty</source>
        <translation>Altitud en referencia de punto está vacía</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="332"/>
        <source>Point code separation is empty</source>
        <translation>Separación en referencia de punto está vacía</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="360"/>
        <source>The file %1 not exist</source>
        <translation>El archivo %1 no existe</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="365"/>
        <source>Can&apos;t open the file %1</source>
        <translation>No se puede abrir el archivo %1</translation>
    </message>
</context>
<context>
    <name>dibSHP</name>
    <message>
        <location filename="../importshp/importshp.cpp" line="59"/>
        <source>File...</source>
        <translation>Archivo...</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="67"/>
        <source>File type:</source>
        <translation>Tipo de archivo:</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="75"/>
        <source>Layer</source>
        <translation>Capa</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="56"/>
        <source>Import ESRI Shapefile</source>
        <translation>Importar archivo Shape de ESRI</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="68"/>
        <location filename="../importshp/importshp.cpp" line="266"/>
        <source>Unknown</source>
        <translation>Desconocido</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="76"/>
        <location filename="../importshp/importshp.cpp" line="89"/>
        <location filename="../importshp/importshp.cpp" line="102"/>
        <location filename="../importshp/importshp.cpp" line="115"/>
        <source>Current</source>
        <translation>Actual</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="77"/>
        <location filename="../importshp/importshp.cpp" line="90"/>
        <location filename="../importshp/importshp.cpp" line="103"/>
        <location filename="../importshp/importshp.cpp" line="116"/>
        <source>From data:</source>
        <translation>De los datos:</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="88"/>
        <source>Color</source>
        <translation>Color</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="101"/>
        <source>Line type</source>
        <translation>Tipo de línea</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="114"/>
        <source>Width</source>
        <translation>Grosor</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="127"/>
        <location filename="../importshp/importshp.cpp" line="213"/>
        <source>Point</source>
        <translation>Punto</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="128"/>
        <source>as Point</source>
        <translation>como Punto</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="129"/>
        <source>as Label:</source>
        <translation>como Etiqueta:</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="141"/>
        <source>Accept</source>
        <translation>Aceptar</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="142"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="167"/>
        <source>Select file</source>
        <translation>Seleccionar archivo</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="217"/>
        <source>Point+Measure</source>
        <translation>Punto+Medida</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="221"/>
        <source>3D Point</source>
        <translation>Punto 3D</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="225"/>
        <source>Multi Point</source>
        <translation>Puntos múltiples</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="229"/>
        <source>Multi Point+Measure</source>
        <translation>Puntos múltiples+Medida</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="233"/>
        <source>3D Multi Point</source>
        <translation>Puntos múltiples 3D</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="237"/>
        <source>Arc</source>
        <translation>Arco</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="241"/>
        <source>Arc+Measure</source>
        <translation>Arco+ Medida</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="245"/>
        <source>3D Arc</source>
        <translation>Arco 3D</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="249"/>
        <source>Polygon</source>
        <translation>Polígono</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="253"/>
        <source>Polygon+Measure</source>
        <translation>Polígono+Medida</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="257"/>
        <source>3D Polygon</source>
        <translation>Polígono 3D</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="261"/>
        <source>Multipatch</source>
        <translation>Multipolígono</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="281"/>
        <source>The file %1 not have extension .shp</source>
        <translation>El archivo %1 no tiene extensión .shp</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="286"/>
        <source>The file %1 not exist</source>
        <translation>El archivo %1 no existe</translation>
    </message>
</context>
<context>
    <name>lc_Geardlg</name>
    <message>
        <location filename="../gear/gear.cpp" line="66"/>
        <source>Draw a gear</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gear/gear.cpp" line="71"/>
        <source>Number of teeth</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gear/gear.cpp" line="79"/>
        <source>Circular pitch</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gear/gear.cpp" line="87"/>
        <source>Pressure angle (deg)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gear/gear.cpp" line="95"/>
        <source>Addendum</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gear/gear.cpp" line="103"/>
        <source>Dedendum</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gear/gear.cpp" line="111"/>
        <source>Type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gear/gear.cpp" line="114"/>
        <source>Spur</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gear/gear.cpp" line="115"/>
        <source>Ring</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gear/gear.cpp" line="119"/>
        <source>Accept</source>
        <translation type="unfinished">Aceptar</translation>
    </message>
    <message>
        <location filename="../gear/gear.cpp" line="124"/>
        <source>Cancel</source>
        <translation type="unfinished">Cancelar</translation>
    </message>
</context>
<context>
    <name>lc_Listdlg</name>
    <message>
        <location filename="../list/list.cpp" line="274"/>
        <source>List entities</source>
        <translation>Listar entidades</translation>
    </message>
</context>
<context>
    <name>lc_Sampledlg</name>
    <message>
        <location filename="../sample/sample.cpp" line="54"/>
        <source>Draw line</source>
        <translation>Dibujar línea</translation>
    </message>
    <message>
        <location filename="../sample/sample.cpp" line="60"/>
        <source>Start X:</source>
        <translation>X inicial:</translation>
    </message>
    <message>
        <location filename="../sample/sample.cpp" line="66"/>
        <source>Start Y:</source>
        <translation>Y inicial:</translation>
    </message>
    <message>
        <location filename="../sample/sample.cpp" line="72"/>
        <source>End X:</source>
        <translation>X final:</translation>
    </message>
    <message>
        <location filename="../sample/sample.cpp" line="78"/>
        <source>End Y:</source>
        <translation>Y final:</translation>
    </message>
    <message>
        <location filename="../sample/sample.cpp" line="86"/>
        <source>Accept</source>
        <translation>Aceptar</translation>
    </message>
    <message>
        <location filename="../sample/sample.cpp" line="91"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../sample/sample.cpp" line="107"/>
        <source>Start X is empty</source>
        <translation>X inicial está vacío</translation>
    </message>
    <message>
        <location filename="../sample/sample.cpp" line="108"/>
        <source>Start Y is empty</source>
        <translation>Y inicial está vacío</translation>
    </message>
    <message>
        <location filename="../sample/sample.cpp" line="109"/>
        <source>End X is empty</source>
        <translation>X final está vacío</translation>
    </message>
    <message>
        <location filename="../sample/sample.cpp" line="110"/>
        <source>End Y is empty</source>
        <translation>Y final está vacío.</translation>
    </message>
    <message>
        <location filename="../sample/sample.cpp" line="132"/>
        <source>Sample plugin</source>
        <translation>Plugin de ejemplo</translation>
    </message>
</context>
<context>
    <name>picPunto</name>
    <message>
        <location filename="../picfile/picfile.cpp" line="65"/>
        <source>File...</source>
        <translation type="unfinished">Archivo...</translation>
    </message>
    <message>
        <location filename="../picfile/picfile.cpp" line="75"/>
        <source>Scale:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../picfile/picfile.cpp" line="79"/>
        <source>Accept</source>
        <translation type="unfinished">Aceptar</translation>
    </message>
    <message>
        <location filename="../picfile/picfile.cpp" line="83"/>
        <source>Cancel</source>
        <translation type="unfinished">Cancelar</translation>
    </message>
    <message>
        <location filename="../picfile/picfile.cpp" line="111"/>
        <source>Select file</source>
        <translation type="unfinished">Seleccionar archivo</translation>
    </message>
    <message>
        <location filename="../picfile/picfile.cpp" line="119"/>
        <source>Scale Factor is empty or invalid</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../picfile/picfile.cpp" line="132"/>
        <source>The file %1 not exist</source>
        <translation type="unfinished">El archivo %1 no existe</translation>
    </message>
    <message>
        <location filename="../picfile/picfile.cpp" line="137"/>
        <source>Can&apos;t open the file %1</source>
        <translation type="unfinished">No se puede abrir el archivo %1</translation>
    </message>
    <message>
        <location filename="../picfile/picfile.cpp" line="144"/>
        <source>%1 objects imported</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../picfile/picfile.cpp" line="166"/>
        <source>picPunto drawLine: first point is empty %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../picfile/picfile.cpp" line="179"/>
        <source>picPunto drawLine: next point is empty %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../picfile/picfile.cpp" line="258"/>
        <location filename="../picfile/picfile.cpp" line="267"/>
        <source>format error in %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>plot</name>
    <message>
        <location filename="../plotequation/plot.cpp" line="21"/>
        <location filename="../plotequation/plot.cpp" line="28"/>
        <source>Plot plugin</source>
        <translation>Plugin de trazado</translation>
    </message>
    <message>
        <source>Draw</source>
        <translation type="obsolete">Dibujar</translation>
    </message>
</context>
<context>
    <name>plotDialog</name>
    <message>
        <location filename="../plotequation/plotdialog.cpp" line="15"/>
        <source>Plot equation</source>
        <translation>Trazar ecuación</translation>
    </message>
    <message>
        <location filename="../plotequation/plotdialog.cpp" line="18"/>
        <source>This plugin allows you to plot mathematical equations.
If you don&apos;t want to use the parametric form, just leave out &quot;Equation2&quot;.
You can use pi when you need the value of pi (i.e. (3*pi)).
Use t or x in your equation as a variable/parameter.
</source>
        <translation>Este plugin permite trazar ecuaciones matemáticas.
Si no quiere usar la forma paramétrica, deje sin cubrir &quot;Ecuación2&quot;.
Puede usar pi cuando necesite el valor de pi (ex. (3 *pi)).
Use t o x en su ecuación como una variable/parámetro.
</translation>
    </message>
    <message>
        <location filename="../plotequation/plotdialog.cpp" line="22"/>
        <source>Equation 1:</source>
        <translation>Ecuación 1:</translation>
    </message>
    <message>
        <location filename="../plotequation/plotdialog.cpp" line="23"/>
        <source>Equation 2:</source>
        <translation>Ecuación 2:</translation>
    </message>
    <message>
        <location filename="../plotequation/plotdialog.cpp" line="26"/>
        <source>start value:</source>
        <translation>valor inicial:</translation>
    </message>
    <message>
        <location filename="../plotequation/plotdialog.cpp" line="27"/>
        <source>end value:</source>
        <translation>valor final:</translation>
    </message>
    <message>
        <location filename="../plotequation/plotdialog.cpp" line="28"/>
        <source>step size:</source>
        <translation>Distancia de paso:</translation>
    </message>
    <message>
        <location filename="../plotequation/plotdialog.cpp" line="32"/>
        <source>Draw</source>
        <translation>Dibujar</translation>
    </message>
    <message>
        <location filename="../plotequation/plotdialog.cpp" line="33"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../plotequation/plotdialog.cpp" line="59"/>
        <source>Line Segments</source>
        <comment>Plot Equation to generate RS_Line segments</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../plotequation/plotdialog.cpp" line="60"/>
        <source>Polyline</source>
        <comment>Plot Equation to generate RS_Polyline</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../plotequation/plotdialog.cpp" line="61"/>
        <source>SplinePoints</source>
        <comment>Plot Equation to generate 2nd spline by LC_SplinePoints</comment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>pointBox</name>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="175"/>
        <source>Layer:</source>
        <translation>Capa:</translation>
    </message>
</context>
<context>
    <name>textBox</name>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="207"/>
        <source>Style:</source>
        <translation>Estilo:</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="208"/>
        <source>Height:</source>
        <translation>Altura:</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="209"/>
        <source>Separation</source>
        <translation>Separación</translation>
    </message>
</context>
</TS>
